@@ -1,4 +1,4 @@
-from .entrypoints.main import main
+from .entrypoint.main import main
 
 if __name__ == '__main__':
     main()
