@@ -3,7 +3,8 @@ from dflow.python import (
     OP,
     OPIO,
     OPIOSign,
-    Artifact
+    Artifact,
+    BigParameter,
 )
 import os, json
 from typing import (
@@ -17,8 +18,6 @@ from pathlib import Path
 from dpgen2.fp.vasp import VaspInputs
 from dpgen2.utils import (
     set_directory,
-    load_object_from_file,
-    dump_object_to_file,
 )
 from dpgen2.constants import (
     vasp_task_pattern,
@@ -43,7 +42,7 @@ class PrepVasp(OP):
     def get_input_sign(cls):
         return OPIOSign({
             "type_map": List[str],
-            "inputs": Artifact(Path),
+            "inputs": BigParameter(VaspInputs),
             "confs" : Artifact(List[Path]),
         })
 
@@ -79,8 +78,7 @@ class PrepVasp(OP):
             - `task_paths`: (`Artifact(List[Path])`) The parepared working paths of the tasks. Contains all input files needed to start the VASP. The order fo the Paths should be consistent with `op["task_names"]`
         """
 
-        inputs_fname = ip['inputs']        
-        inputs = load_object_from_file(inputs_fname)
+        inputs = ip['inputs']        
         confs = ip['confs']
         type_map = ip['type_map']
 
