@@ -45,10 +45,6 @@ from dpgen2.exploration.task import ExplorationTask, ExplorationTaskGroup, Explo
 from dpgen2.exploration.report import ExplorationReport
 from dpgen2.exploration.scheduler import ConvergenceCheckStageScheduler
 from dpgen2.fp.vasp import VaspInputs
-from dpgen2.utils import (
-    load_object_from_file,
-    dump_object_to_file,
-)
 
 mocked_template_script = { 'seed' : 1024, 'data': [] }
 mocked_numb_models = 3
@@ -353,8 +349,7 @@ class MockedPrepVasp(PrepVasp):
         confs = ip['confs']
         # incar_temp = ip['incar_temp']
         # potcars = ip['potcars']
-        vasp_input_fname = ip['inputs']
-        vasp_input = load_object_from_file(vasp_input_fname)
+        vasp_input = ip['inputs']
         type_map = ip['type_map']
         if not (type_map == ['H', 'O']):
             raise FatalError
