@@ -41,7 +41,6 @@ class TestPrepVasp(unittest.TestCase):
         ms_1.to_deepmd_npy('data-1')
         self.confs = ['data-0', 'data-1']
         self.confs = [Path(ii) for ii in self.confs]    
-        self.vi_fname = Path('vasp_inputs.dat')
         self.type_map = ['H', 'O']
         
     def tearDown(self):
@@ -58,9 +57,6 @@ class TestPrepVasp(unittest.TestCase):
             tname = Path(vasp_task_pattern%ii)
             if tname.is_dir():
                 shutil.rmtree(tname)
-        for ii in [self.vi_fname]:
-            if ii.is_file():
-                os.remove(ii)
 
     def check_sys(self, ss0, ss1):
         self.assertEqual(ss0['atom_numbs'], ss1['atom_numbs'])
@@ -78,10 +74,9 @@ Gamma
         iincar = 'template.incar'
         ipotcar = {'H' : 'POTCAR_H', 'O' : 'POTCAR_O'}
         vi = VaspInputs(0.1, True, iincar, ipotcar)
-        dump_object_to_file(vi, self.vi_fname)
         op = PrepVasp()
         opout = op.execute(OPIO({
-            'inputs': self.vi_fname,
+            'inputs': vi,
             'confs' : self.confs,
             'type_map' : self.type_map,
         }))
