@@ -143,8 +143,6 @@ class TestBlockCL(unittest.TestCase):
         self.template_script = mocked_template_script
         
         self.task_group_list = MockedExplorationTaskGroup()
-        dump_object_to_file(self.task_group_list, 'lmp_task_grp.dat')
-        self.task_group_list = upload_artifact('lmp_task_grp.dat')
 
         self.conf_selector = MockedConfSelector()
         self.type_map = ['H', 'O']
@@ -158,9 +156,6 @@ class TestBlockCL(unittest.TestCase):
             self.incar,
             {'foo': self.potcar},
         )
-        self.vasp_inputs_fname = Path('vasp_inputs.dat')
-        self.vasp_inputs_arti = upload_artifact(
-            dump_object_to_file(self.vasp_inputs, self.vasp_inputs_fname))
 
     def setUp(self):
         self.name = 'iter-002'
@@ -187,7 +182,7 @@ class TestBlockCL(unittest.TestCase):
             name = Path(model_name_pattern % ii)
             if name.is_file():
                 os.remove(name)
-        for ii in [self.incar, self.potcar, self.vasp_inputs_fname]:
+        for ii in [self.incar, self.potcar]:
             if ii.is_file():
                 os.remove(ii)
 
@@ -211,10 +206,10 @@ class TestBlockCL(unittest.TestCase):
                 "lmp_config" : {},
                 "conf_selector" : self.conf_selector,
                 "fp_config" : {},
+                'fp_inputs' : self.vasp_inputs,
+                "lmp_task_grp" : self.task_group_list,
             },
             artifacts = {
-                'fp_inputs' : self.vasp_inputs_arti,
-                "lmp_task_grp" : self.task_group_list,
                 "init_models" : self.init_models,
                 "init_data" : self.init_data,
                 "iter_data" : self.iter_data,
