@@ -103,18 +103,12 @@ class TestPrepLmp(unittest.TestCase):
         self.ngrp = 2
         self.ntask_per_grp = 3
         self.task_group_list = make_task_group_list(self.ngrp, self.ntask_per_grp)
-        with open('lmp_task_grp.dat', 'wb') as fp:
-            pickle.dump(self.task_group_list, fp)
-        self.task_group_list = Path('lmp_task_grp.dat')
         
     def tearDown(self):
         for ii in range(self.ngrp * self.ntask_per_grp):
             work_path = Path(lmp_task_pattern % ii)
             if work_path.is_dir():
                 shutil.rmtree(work_path)
-        task_grp = Path('lmp_task_grp.dat')
-        if task_grp.is_file():
-            os.remove(task_grp)
 
     def test(self):
         op = PrepLmp()
@@ -199,9 +193,6 @@ class TestPrepRunLmp(unittest.TestCase):
         self.ngrp = 2
         self.ntask_per_grp = 3
         self.task_group_list = make_task_group_list(self.ngrp, self.ntask_per_grp)
-        with open('lmp_task_grp.dat', 'wb') as fp:
-            pickle.dump(self.task_group_list, fp)
-        self.task_group_list = upload_artifact('lmp_task_grp.dat')
         self.nmodels = mocked_numb_models
         self.model_list = []
         for ii in range(self.nmodels):
@@ -210,6 +201,7 @@ class TestPrepRunLmp(unittest.TestCase):
             self.model_list.append(model)
         self.models = upload_artifact(self.model_list)
 
+
     def tearDown(self):
         for ii in range(self.nmodels):
             model = Path(f'model{ii}.pb')
@@ -219,9 +211,6 @@ class TestPrepRunLmp(unittest.TestCase):
             work_path = Path(f'task.{ii:06d}')
             if work_path.is_dir():
                 shutil.rmtree(work_path)
-        task_grp = Path('lmp_task_grp.dat')
-        if task_grp.is_file():
-            os.remove(task_grp)
         
 
     def check_run_lmp_output(
@@ -259,9 +248,9 @@ class TestPrepRunLmp(unittest.TestCase):
             template = steps,
             parameters = {
                 "lmp_config" : {},
+                "lmp_task_grp" : self.task_group_list,
             },
             artifacts = {
-                "lmp_task_grp" : self.task_group_list,
                 "models" : self.models,
             },
         )
